@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include "pimcommon_export.h"
 
 #include <PimCommon/SpellCheckLineEdit>
-namespace PimCommonAutoCorrection
+namespace TextAutoCorrection
 {
 class AutoCorrection;
 }
@@ -28,9 +28,9 @@ public:
     explicit LineEditWithAutoCorrection(QWidget *parent, const QString &configFile);
     ~LineEditWithAutoCorrection() override;
 
-    Q_REQUIRED_RESULT PimCommonAutoCorrection::AutoCorrection *autocorrection() const;
+    Q_REQUIRED_RESULT TextAutoCorrection::AutoCorrection *autocorrection() const;
+    void setAutocorrection(TextAutoCorrection::AutoCorrection *autocorrect);
 
-    void setAutocorrection(PimCommonAutoCorrection::AutoCorrection *autocorrect);
     void setAutocorrectionLanguage(const QString &language);
 
 protected:
