@@ -1,14 +1,19 @@
 /*
-  SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "purposemenuwidget.h"
+#include "purpose_version.h"
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <Purpose/AlternativesModel>
+#if PURPOSE_VERSION < QT_VERSION_CHECK(5, 104, 0)
 #include <PurposeWidgets/Menu>
+#else
+#include <Purpose/Menu>
+#endif
 #include <QJsonArray>
 #include <QTemporaryFile>
 #include <QUrl>
@@ -20,7 +25,6 @@ PurposeMenuWidget::PurposeMenuWidget(QWidget *parentWidget, QObject *parent)
 {
     mShareMenu = new Purpose::Menu(mParentWidget);
     mShareMenu->setObjectName(QStringLiteral("purposesharemenu"));
-    mShareMenu->model()->setPluginType(QStringLiteral("Export"));
     connect(mShareMenu, &Purpose::Menu::aboutToShow, this, &PurposeMenuWidget::slotInitializeShareMenu);
     connect(mShareMenu, &Purpose::Menu::finished, this, &PurposeMenuWidget::slotShareActionFinished);
 }
@@ -45,6 +49,7 @@ void PurposeMenuWidget::slotInitializeShareMenu()
     mTemporaryShareFile->close();
     mShareMenu->model()->setInputData(QJsonObject{{QStringLiteral("urls"), QJsonArray{{QUrl::fromLocalFile(mTemporaryShareFile->fileName()).toString()}}},
                                                   {QStringLiteral("mimeType"), {QStringLiteral("text/plain")}}});
+    mShareMenu->model()->setPluginType(QStringLiteral("Export"));
     mShareMenu->reload();
 }
 
