@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BLACKLISTBALOOEMAILUTIL_H
-#define BLACKLISTBALOOEMAILUTIL_H
+#pragma once
 
 #include "pimcommonakonadi_private_export.h"
 #include <QHash>
@@ -27,4 +26,3 @@ private:
     QHash<QString, bool> mNewBlackList;
 };
 }
-#endif // BLACKLISTBALOOEMAILUTIL_H
